﻿using System;
using System.Drawing;
using System.Collections.Generic;

using MonoTouch.Foundation;
using MonoTouch.UIKit;
using System.IO;
using System.Threading.Tasks;
using MonoTouch.QuickLook;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Tables;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Grid;
using Syncfusion.Compression;
using System.Reflection;
using System.Linq;
using System.Xml.Linq;
using Syncfusion.Drawing;
namespace PdfLightTableTesting
{
	public partial class DetailViewController : UIViewController
	{
		object detailItem;

		public DetailViewController (IntPtr handle) : base (handle)
		{
		}

		public void SetDetailItem (object newDetailItem)
		{
			if (detailItem != newDetailItem) {
				detailItem = newDetailItem;

				// Update the view
				ConfigureView ();
			}
		}

		void ConfigureView ()
		{
			// Update the user interface for the detail item
			if (IsViewLoaded && detailItem != null)
				detailDescriptionLabel.Text = detailItem.ToString ();
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			// Perform any additional setup after loading the view, typically from a nib.
			ConfigureView ();
		}
		PdfPen borderPen; 
		PdfPen transparentPen;
		float cellSpacing = 7f;
		PdfLightTable pdfLightTable = null;
		partial void UIButton7_TouchUpInside (UIButton sender)
		{
			IEnumerable<Products> products = DataProvider.GetProducts();

			//Creating the new PDF document.
			PdfDocument document=new PdfDocument();
			PdfPage page=document.Pages.Add();
			borderPen = new PdfPen(PdfBrushes.DarkGray, .3f);
			borderPen.LineCap = PdfLineCap.Square;
			transparentPen = new PdfPen(PdfBrushes.Transparent, .3f);
			transparentPen.LineCap = PdfLineCap.Square;
			PdfStandardFont font = new PdfStandardFont(PdfFontFamily.TimesRoman, 8f);
			# region PdfLightTable
			pdfLightTable = new PdfLightTable();
			pdfLightTable.DataSource = products;
			pdfLightTable.Style.DefaultStyle.BorderPen = transparentPen;

			for (int i = 0; i < pdfLightTable.Columns.Count; i++)
			{
				if (i % 2 == 0)
					pdfLightTable.Columns[i].Width = 1.2f;
			}

			pdfLightTable.Style.CellSpacing = cellSpacing;
			pdfLightTable.BeginCellLayout += new BeginCellLayoutEventHandler(pdfLightTable_BeginCellLayout);
			pdfLightTable.Style.DefaultStyle.Font = font;
			//Drawing the table
			PdfLayoutResult result = pdfLightTable.Draw(page,new Syncfusion.Drawing.PointF(0,0));
			# endregion

			MemoryStream stream = new MemoryStream();
			document.Save(stream);
			document.Close(true);
			Save("table.pdf","application/pdf", stream);
		}
		void pdfLightTable_BeginCellLayout(object sender, BeginCellLayoutEventArgs args)
		{
			if (args.RowIndex > -1 && args.CellIndex > -1)
			{
				float x = args.Bounds.X;
				float y = args.Bounds.Y;
				float width = args.Bounds.Right;
				float height = args.Bounds.Bottom;

				if (args.Value == "dummy")
				{
					args.Skip = true;
					return;
				}

				if (args.CellIndex % 2 == 0 && !string.IsNullOrEmpty(args.Value))
				{
					//Drawing the image
					args.Skip = true;
					PdfImage image = PdfImage.FromStream (ToStream("pdf.png"));
					Syncfusion.Drawing.RectangleF rect = args.Bounds;
					args.Graphics.DrawImage (image, new Syncfusion.Drawing.RectangleF (rect.X + 2, rect.Y + 2, rect.Width - 2, rect.Height - 2));
				}

			
			}
		}
		internal sealed class DataProvider
		{
			public static IEnumerable<Products> GetProducts()
			{

				Stream xmlStream = typeof(DetailViewController).GetTypeInfo().Assembly.GetManifestResourceStream("PdfLightTableTesting.Products.xml");

				using (StreamReader reader = new StreamReader(xmlStream, true))
				{
					return XElement.Parse(reader.ReadToEnd())
						.Elements("Products")
						.Select(c => new Products
							{
								Image1 = c.Element("Image1").Value,
								Description1 = c.Element("Description1").Value,
								Image2 = c.Element("Image2").Value,
								Description2 = c.Element("Description2").Value,
								Image3 = (c.Element("Image3") != null) ? c.Element("Image3").Value : "dummy",
								Description3 = (c.Element("Description3") != null) ? c.Element("Description3").Value : "dummy",
							});
				}
			}
				
		}
		#region Products
		public class Products
		{
			public string Image1 { get; set; }
			public string Description1 { get; set; }
			public string Image2 { get; set; }
			public string Description2 { get; set; }
			public string Image3 { get; set; }
			public string Description3 { get; set; }
		}
		#endregion

		public void Save (string filename, string contentType, MemoryStream stream)
		{
			string path = Environment.GetFolderPath (Environment.SpecialFolder.Personal);
			string filePath = Path.Combine (path, filename);
			try {
				FileStream fileStream = File.Open (filePath, FileMode.Create);
				stream.Position = 0;
				stream.CopyTo (fileStream);
				fileStream.Flush ();
				fileStream.Close ();
			}
			catch (Exception e) {
			}
			UIViewController currentController = UIApplication.SharedApplication.KeyWindow.RootViewController;
			while (currentController.PresentedViewController != null)
				currentController = currentController.PresentedViewController;
			UIView currentView = currentController.View;
			QLPreviewController qlPreview = new QLPreviewController ();
			QLPreviewItem item = new QLPreviewItemBundle (filename, filePath);
			qlPreview.DataSource = new PreviewControllerDS (item);
			//UIViewController uiView = currentView as UIViewController;
			currentController.PresentViewController (qlPreview, true, null);
		}

		public Stream ToStream(string path)
		{
			Stream stream = new MemoryStream();
			stream =  UIImage.FromBundle(path).AsJPEG().AsStream();
			//stream.Position = 0;
			return stream;
		}
	}
}

